import React from "react";
import { makeStyles } from "@material-ui/core/styles";
import PropTypes from "prop-types";
import Table from "@material-ui/core/Table";
import TableBody from "@material-ui/core/TableBody";
import TableCell from "@material-ui/core/TableCell";
import TableContainer from "@material-ui/core/TableContainer";
import TableHead from "@material-ui/core/TableHead";
import TableRow from "@material-ui/core/TableRow";
import Paper from "@material-ui/core/Paper";
import Skeleton from "@material-ui/lab/Skeleton";
import { useHistory } from "react-router-dom";

const useStyles = makeStyles((theme) => ({
  table: {
    minWidth: 650,
    overflowY: "scroll"
  },
  tableContainer: {
    margin: 24
  },
  tableRow: {
    "&:hover": {
      cursor: "pointer",
      backgroundColor: theme.palette.background.default
    }
  }
}));

const createNumbers = (numbers) => [...Array(31)].map((_value, index) => (numbers ? numbers[index + 1] : index + 1));

function createData({ month, year, ...row }) {
  return { month, year, sunValues: createNumbers(row) };
}

const headerTemplate = {
  year: "Year",
  month: "Měsíc",
  labels: createNumbers()
};

const DataTable = ({ rows, initialized }) => {
  const history = useHistory();
  const classes = useStyles();
  return (
    <TableContainer className={classes.tableContainer} component={Paper}>
      <Table className={classes.table} aria-label="simple table">
        <TableHead>
          <TableRow>
            <TableCell>{headerTemplate.year}</TableCell>
            <TableCell align="right">{headerTemplate.month}</TableCell>
            {headerTemplate.labels.map((label) => (
              <TableCell key={label}>{label}</TableCell>
            ))}
          </TableRow>
        </TableHead>
        <TableBody>
          {initialized &&
            rows.map((data, index) => {
              const row = createData(data);
              return (
                <TableRow key={`${row.name}-${index}`} onClick={() => history.push(`/detail/${data._id}`)} className={classes.tableRow}>
                  <TableCell component="th" scope="row">
                    {row.year}
                  </TableCell>
                  <TableCell align="right">{row.month}</TableCell>
                  {row.sunValues.map((number, index) => (
                    <TableCell key={`${number}-${index}`}>{number}</TableCell>
                  ))}
                </TableRow>
              );
            })}
          {!initialized &&
            [...new Array(10)].map((_i, key) => (
              <TableRow key={`${key}-loader`} className={classes.tableRow}>
                <TableCell scope="row" colSpan={headerTemplate.labels.length + 1}>
                  <Skeleton />
                </TableCell>
              </TableRow>
            ))}
        </TableBody>
      </Table>
    </TableContainer>
  );
};

DataTable.propTypes = {
  rows: PropTypes.arrayOf(
    PropTypes.shape({
      month: PropTypes.node,
      year: PropTypes.node
    })
  ),
  initialized: PropTypes.bool
};

DataTable.defaultProps = {
  rows: [],
  initialized: false
};

export default DataTable;
