import React, { useState } from "react";
import PropTypes from "prop-types";
import { useAuth0 } from "../react-auth0-spa";
import clsx from "clsx";
import { makeStyles } from "@material-ui/core/styles";
import AppBar from "@material-ui/core/AppBar";
import Toolbar from "@material-ui/core/Toolbar";
import Typography from "@material-ui/core/Typography";
import IconButton from "@material-ui/core/IconButton";
import Badge from "@material-ui/core/Badge";
import NotificationsIcon from "@material-ui/icons/Notifications";
import MenuIcon from "@material-ui/icons/Menu";
import Button from "@material-ui/core/Button";
import Avatar from "@material-ui/core/Avatar";
import Menu from "@material-ui/core/Menu";
import MenuItem from "@material-ui/core/MenuItem";
import { useHistory } from "react-router-dom";

const drawerWidth = 240;

const useStyles = makeStyles((theme) => {
  console.log(theme);
  return {
    appBar: {
      zIndex: theme.zIndex.drawer + 1,
      transition: theme.transitions.create(["width", "margin"], {
        easing: theme.transitions.easing.sharp,
        duration: theme.transitions.duration.leavingScreen
      })
    },
    appBarShift: {
      marginLeft: drawerWidth,
      width: `calc(100% - ${drawerWidth}px)`,
      transition: theme.transitions.create(["width", "margin"], {
        easing: theme.transitions.easing.sharp,
        duration: theme.transitions.duration.enteringScreen
      })
    },
    toolbar: {
      paddingRight: 24 // keep right padding when drawer closed
    },
    menuButton: {
      marginRight: 36
    },
    menuButtonHidden: {
      display: "none"
    },
    title: {
      flexGrow: 1
    },
    avatar: {
      color: theme.palette.common.white
    },
    avatarCircle: {
      marginRight: theme.spacing(2)
    }
  };
});

const NavBar = ({ open, handleOpen }) => {
  const { user, isAuthenticated, loginWithRedirect, logout } = useAuth0();
  const classes = useStyles();
  const [anchorEl, setAnchorEl] = useState(null);
  const history = useHistory();

  const handleClick = (event) => {
    setAnchorEl(event.currentTarget);
  };

  const handleClose = () => {
    setAnchorEl(null);
  };

  const logoutWithRedirect = () =>
    logout({
      returnTo: window.location.origin
    });

  return (
    <AppBar position="absolute" className={clsx(classes.appBar, isAuthenticated && open && classes.appBarShift)}>
      <Toolbar className={classes.toolbar}>
        {isAuthenticated && (
          <IconButton
            edge="start"
            color="inherit"
            aria-label="open drawer"
            onClick={handleOpen}
            className={clsx(classes.menuButton, open && classes.menuButtonHidden)}
          >
            <MenuIcon />
          </IconButton>
        )}
        <Typography component="h1" variant="h6" color="inherit" noWrap className={classes.title}>
          Dashboard
        </Typography>
        {isAuthenticated && (
          <IconButton color="inherit">
            <Badge badgeContent={4} color="secondary">
              <NotificationsIcon />
            </Badge>
          </IconButton>
        )}
        {!isAuthenticated && (
          <Button id="qsLoginBtn" variant="contained" type="button" onClick={() => loginWithRedirect({})}>
            Log in
          </Button>
        )}
        {isAuthenticated && (
          <div>
            <Button className={clsx(classes.avatar)} aria-controls="simple-menu" aria-haspopup="true" onClick={handleClick}>
              <Avatar src={user.picture} alt="Profile" className={clsx(classes.avatarCircle)} />
              {user.name}
            </Button>
            <Menu id="simple-menu" anchorEl={anchorEl} keepMounted open={Boolean(anchorEl)} onClose={handleClose}>
              <MenuItem
                onClick={() => {
                  handleClose();
                  history.push("/profile");
                }}
              >
                Profile
              </MenuItem>
              <MenuItem
                onClick={() => {
                  handleClose();
                  logoutWithRedirect();
                }}
              >
                Log out
              </MenuItem>
            </Menu>
          </div>
        )}
      </Toolbar>
    </AppBar>
  );
};

NavBar.propTypes = {
  open: PropTypes.bool,
  handleOpen: PropTypes.func
};

export default NavBar;
