import React, { useEffect, useState } from "react";
import Api from "../utils/api";
import TextField from "@material-ui/core/TextField";
import Grid from "@material-ui/core/Grid";
import Toolbar from "@material-ui/core/Toolbar";
import Autocomplete from "@material-ui/lab/Autocomplete";
import { ResponsiveLine } from "@nivo/line";
import mean from "lodash/mean";

const queryBuilder = ({ filter }) => {
  return `q={${filter ? `"year": ${filter}` : ""}}`;
};

const Chart = () => {
  const [years, setYears] = useState([]);
  const [data, setData] = useState([]);
  const [filter, setFilter] = useState(undefined);
  const [initialized, setInitialized] = useState(false);

  const onFilter = (_e, filter) => {
    setFilter(filter);
  };

  useEffect(() => {
    Api.sun.get(`rest/sunshine?q={}&h={"$fields": {"year": 1}}`).then((data) => setYears([...new Set(data.map(({ year }) => `${year}`))]));
  }, []);

  useEffect(() => {
    setInitialized(false);
    Api.sun.get(`rest/sunshine?${queryBuilder({ filter })}`).then((data) => {
      setData(data);
      setInitialized(true);
    });
  }, [filter]);

  const chartData = data.reduce(
    (acc, { _id, year, month, ...item }) => ({
      ...acc,
      [year]: {
        id: year,
        color: "hsl(95, 70%, 50%)",
        data: [...((acc[year] && acc[year].data) || []), { x: month, y: mean(Object.values(item)) }]
      }
    }),
    {}
  );

  return (
    <div style={{ height: "100%" }}>
      <h1>Average sunshine in a month</h1>
      {initialized && (
        <ResponsiveLine
          data={Object.values(chartData)}
          keys={["val"]}
          indexBy="key"
          margin={{ top: 50, right: 110, bottom: 50, left: 60 }}
          xScale={{ type: "point" }}
          yScale={{ type: "linear", min: "auto", max: "auto", stacked: true, reverse: false }}
          axisTop={null}
          axisRight={null}
          axisBottom={{
            orient: "bottom",
            tickSize: 5,
            tickPadding: 5,
            tickRotation: 0,
            legend: "month",
            legendOffset: 36,
            legendPosition: "middle"
          }}
          axisLeft={{
            orient: "left",
            tickSize: 5,
            tickPadding: 5,
            tickRotation: 0,
            legend: "Sunshine",
            legendOffset: -40,
            legendPosition: "middle"
          }}
          colors={{ scheme: "nivo" }}
          pointSize={10}
          pointColor={{ theme: "background" }}
          pointBorderWidth={2}
          pointBorderColor={{ from: "serieColor" }}
          pointLabel="y"
          pointLabelYOffset={-12}
          useMesh={true}
          legends={[
            {
              anchor: "bottom-right",
              direction: "column",
              justify: false,
              translateX: 100,
              translateY: 0,
              itemsSpacing: 0,
              itemDirection: "left-to-right",
              itemWidth: 80,
              itemHeight: 20,
              itemOpacity: 0.75,
              symbolSize: 12,
              symbolShape: "circle",
              symbolBorderColor: "rgba(0, 0, 0, .5)",
              effects: [
                {
                  on: "hover",
                  style: {
                    itemBackground: "rgba(0, 0, 0, .03)",
                    itemOpacity: 1
                  }
                }
              ]
            }
          ]}
        />
      )}
    </div>
  );
};

export default Chart;
