import React, { useEffect, useState } from "react";
import Api from "../utils/api";
import Pagination from "@material-ui/lab/Pagination";
import TextField from "@material-ui/core/TextField";
import DataTable from "../components/DataTable";
import Grid from "@material-ui/core/Grid";
import Toolbar from "@material-ui/core/Toolbar";
import Autocomplete from "@material-ui/lab/Autocomplete";

const queryBuilder = ({ max = 15, skip = 0, filter, sortBy }) => {
  return `q={${filter ? `"year": ${filter}` : ""}}&max=${max}&skip=${skip}`;
};

const HomePage = () => {
  const [years, setYears] = useState([]);
  const [data, setData] = useState([]);
  const [{ max, skip, count, filterValue }, setPagination] = useState({
    max: 15,
    skip: 0,
    count: 0,
    filterValue: ""
  });
  const [initialized, setInitialized] = useState(false);

  const onFilter = (e, filter) => {
    setPagination((prevPagination) => ({
      ...prevPagination,
      filterValue: filter
    }));
  };

  const handlePagination = (_event, page) => {
    setInitialized(false);
    setPagination((prevPagination) => ({
      ...prevPagination,
      skip: (page - 1) * prevPagination.max
    }));
  };
  useEffect(() => {
    setInitialized(false);
    Promise.all([
      Api.sun.get(`rest/sunshine?${queryBuilder({ max, skip, filter: filterValue })}&totals=true`).then(({ data, totals }) => {
        setData(data);
        setPagination((prevPagination) => ({ ...prevPagination, count: totals.total }));
      }),
      Api.sun.get(`rest/sunshine?q={}&h={"$fields": {"year": 1}}`).then((data) => setYears([...new Set(data.map(({ year }) => `${year}`))]))
    ]).then(() => setInitialized(true));
  }, [skip, filterValue]);

  const addMessage = () => Api.updateData("professors.messages", { message: "Hola" }, "add");
  const replaceMessage = () => Api.updateData("professors.messages", { message: "Hola" }, "replace");
  return (
    <div>
      <h1>Home page</h1>
      <button onClick={addMessage}>Add message</button>
      <button onClick={replaceMessage}>replace message</button>
      <Toolbar>
        <Grid container spacing={3} justify="space-between">
          <Grid item>
            <Autocomplete
              style={{ minWidth: "150px" }}
              options={years}
              id="year-picker"
              value={filterValue}
              onChange={onFilter}
              disabled={!initialized}
              renderInput={(params) => <TextField {...params} label="Select year" margin="normal" />}
            />
          </Grid>
          <Grid item>
            <Pagination
              style={{ marginTop: "12px" }}
              count={Math.ceil(count / max)}
              page={skip / max + 1}
              onChange={handlePagination}
              variant="outlined"
              shape="rounded"
              showFirstButton
              showLastButton
            />
          </Grid>
        </Grid>
      </Toolbar>
      <DataTable rows={data} initialized={initialized} />
    </div>
  );
};

export default HomePage;
