import React from "react";
import { Form, Field } from "react-final-form";
import TextField from "@material-ui/core/TextField";
import Grid from "@material-ui/core/Grid";
import "./profile.css";
import Loading from "../components/Loading";
import { useAuth0 } from "../react-auth0-spa";

const FormTextField = ({ input, meta, ...props }) => (
  <Grid item xs={12}>
    <TextField {...input} {...props} fullWidth />
  </Grid>
);

const Profile = () => {
  const { loading, user, updateProfile, setUser } = useAuth0();
  const initialValues = {
    name: user.name,
    nickname: user.nickname,
    picture: user.picture
  };

  if (loading || !user) {
    return <Loading />;
  }

  const handleSubmit = (values) =>
    updateProfile(values).then(({ name, nickname, picture }) =>
      setUser({
        name,
        nickname,
        picture
      })
    );

  return (
    <div>
      <img className="profile-image" src={user.picture} alt="Profile" />
      <div>
        <Grid container>
          <Form initialValues={initialValues} onSubmit={handleSubmit}>
            {({ handleSubmit }) => (
              <form onSubmit={handleSubmit} style={{ width: "100%" }}>
                <Field name="name" component={FormTextField} label="Name" type="text" />
                <Field name="nickname" component={FormTextField} label="Nickname" type="text" />
                <Field name="picture" component={FormTextField} label="Picture" type="text" />
                <button type="submit">Submit</button>
              </form>
            )}
          </Form>
        </Grid>
      </div>
      <div>
        <pre>{JSON.stringify(user, null, 2)}</pre>
      </div>
    </div>
  );
};

export default Profile;
